@@ -8,6 +8,7 @@ import unittest
 from urllib.parse import urljoin
 
 from pulp_smash import api, cli, config, exceptions
+from pulp_smash.pulp3.bindings import monitor_task
 from pulp_smash.pulp3.utils import (
     delete_orphans,
     get_content,
@@ -20,7 +21,6 @@ from pulp_container.tests.functional.utils import (
     gen_container_client,
     gen_container_remote,
     get_docker_hub_remote_blobsums,
-    monitor_task,
     BearerTokenAuth,
     AuthenticationHeaderQueries,
 )
@@ -91,7 +91,7 @@ class PullContentTestCase(unittest.TestCase):
             distribution_response = cls.distributions_api.create(
                 ContainerContainerDistribution(**gen_distribution(repository=cls.repo.pulp_href))
             )
-            created_resources = monitor_task(distribution_response.task)
+            created_resources = monitor_task(distribution_response.task).created_resources
             distribution = cls.distributions_api.read(created_resources[0])
             cls.distribution_with_repo = cls.distributions_api.read(distribution.pulp_href)
             cls.teardown_cleanups.append(
@@ -104,7 +104,7 @@ class PullContentTestCase(unittest.TestCase):
                     **gen_distribution(repository_version=cls.repo.latest_version_href)
                 )
             )
-            created_resources = monitor_task(distribution_response.task)
+            created_resources = monitor_task(distribution_response.task).created_resources
             distribution = cls.distributions_api.read(created_resources[0])
             cls.distribution_with_repo_version = cls.distributions_api.read(distribution.pulp_href)
             cls.teardown_cleanups.append(
@@ -153,15 +153,17 @@ class PullContentTestCase(unittest.TestCase):
 
         authenticate_header = content_response.headers["Www-Authenticate"]
         queries = AuthenticationHeaderQueries(authenticate_header)
-        content_response = self.client.get(
+        content_response = requests.get(
             queries.realm, params={"service": queries.service, "scope": queries.scope}
         )
+        content_response.raise_for_status()
         token = content_response.json()["token"]
-        content_response = self.client.get(
+        content_response = requests.get(
             latest_image_url,
             auth=BearerTokenAuth(token),
             headers={"Accept": MEDIA_TYPE.MANIFEST_V1},
         )
+        content_response.raise_for_status()
         base_content_type = content_response.headers["Content-Type"].split(";")[0]
         self.assertIn(base_content_type, {MEDIA_TYPE.MANIFEST_V1, MEDIA_TYPE.MANIFEST_V1_SIGNED})
 
@@ -315,7 +317,7 @@ class PullOnDemandContentTestCase(unittest.TestCase):
             distribution_response = cls.distributions_api.create(
                 ContainerContainerDistribution(**gen_distribution(repository=cls.repo.pulp_href))
             )
-            created_resources = monitor_task(distribution_response.task)
+            created_resources = monitor_task(distribution_response.task).created_resources
 
             distribution = cls.distributions_api.read(created_resources[0])
             cls.distribution_with_repo = cls.distributions_api.read(distribution.pulp_href)
@@ -329,7 +331,7 @@ class PullOnDemandContentTestCase(unittest.TestCase):
                     **gen_distribution(repository_version=cls.repo.latest_version_href)
                 )
             )
-            created_resources = monitor_task(distribution_response.task)
+            created_resources = monitor_task(distribution_response.task).created_resources
             distribution = cls.distributions_api.read(created_resources[0])
             cls.distribution_with_repo_version = cls.distributions_api.read(distribution.pulp_href)
             cls.teardown_cleanups.append(
